@@ -11,8 +11,8 @@ use Time::Seconds;
 use Carp qw( carp croak );
 use Digest::MD5 qw( md5_hex );
 
-$VERSION = '0.29';
-my $SCHEMA_VER = 10;
+$VERSION = '0.32';
+my $SCHEMA_VER = 11;
 
 # first, detect if Encode is available - it's not under 5.6. If we _are_
 # under 5.6, give up - we'll just have to hope that nothing explodes. This
@@ -111,8 +111,7 @@ sub _init {
         my $dsn = $self->_dsn($dbname, $dbhost, $dbport)
             or croak "No data source string provided by class";
         $self->{_dbh} = DBI->connect( $dsn, $dbuser, $dbpass,
-                      { PrintError => 0, RaiseError => 1,
-                        AutoCommit => 1 } )
+                                      $self->_get_dbh_connect_attr )
             or croak "Can't connect to database $dbname using $dsn: "
                    . DBI->errstr;
     }
@@ -127,6 +126,16 @@ sub _init {
     return $self;
 }
 
+# Internal method to get attributes for passing to DBI->connect().
+# Override in subclasses to add database-dependent attributes.
+sub _get_dbh_connect_attr {
+    return {
+             PrintError => 0,
+             RaiseError => 1,
+             AutoCommit => 1,
+    };
+}
+
 # Internal method, used to handle the logic of how to add up return
 #  values from pre_ plugins
 sub handle_pre_plugin_ret {
@@ -714,6 +723,15 @@ sub rename_node {
     my $dbh = $self->dbh;
     my $formatter = $wiki->{_formatter};
 
+    # For formatters that support it, run the new name through the node name
+    # to param conversion and back again, to make sure any necessary munging
+    # gets done.
+    if ( $formatter->can( "node_name_to_node_param" )
+         && $formatter->can( "node_param_to_node_name" ) ) {
+        $new_name = $formatter->node_param_to_node_name(
+                        $formatter->node_name_to_node_param( $new_name ) );
+    }
+
     my $timestamp = $self->_get_timestamp();
 
     # Call pre_rename on any plugins, in case they want to tweak anything
@@ -1050,7 +1068,8 @@ sub delete_node {
     # Skip out early if we're trying to delete a nonexistent version.
     my %verdata = $self->retrieve_node( name => $name, version => $version );
     unless($verdata{version}) {
-        warn("Asked to delete non existant version $version of node $node_id ($name)");
+        warn( "Asked to delete nonexistent version $version of node "
+               . "$node_id ($name)" );
         return 1;
     }
 
@@ -1268,12 +1287,12 @@ element of the array is a reference to a hash with the following entries:
 
 =item * B<name>: the name of the node
 
-=item * B<version>: the latest version number
+=item * B<version>: the version number of the node
 
-=item * B<last_modified>: the timestamp of when it was last modified
+=item * B<last_modified>: timestamp showing when this version was written
 
 =item * B<metadata>: a ref to a hash containing any metadata attached
-to the current version of the node
+to this version of the node
 
 =back
 
@@ -1431,7 +1450,8 @@ sub _find_recent_changes_by_criteria {
     # Figure out which table we should be joining to to check the dates and
     # versions - node or content.
     my $date_table = "node";
-    if ( $include_all_changes || $new_only ) {
+    if ( $include_all_changes || $new_only
+           || $metadata_was || $metadata_wasnt ) {
         $date_table = "content";
         $use_content_table = 1;
     }
@@ -2201,4 +2221,8 @@ sub charset_encode {
     return @input;
 }
 
+=back
+
+=cut
+
 1;
